# libpykaライブラリ

## libpykaの概要
Pythonの一般的ユーティリティライブラリ。
DBや文字列操作の便利な関数などが利用できる。
libpykaライブラリはその中に複数のパッケージで構成されている。
DB関連はdbパッケージ。
文字列や一般的なモジュールはutilsパッケージ。

## libpykaのパッケージの説明
### dbパッケージ
DB関連のパッケージでDBは主にPostgreSQLを使用する。
postgresモジュールでPostgreSQL関連の便利な関数を指定できる。

### utilsパッケージ
主に文字列操作や基本的な便利な関数が格納されたモジュール。



